# cipher-parse

**Pre- and post-processing for the phase-field code [CIPHER](https://github.com/micmog/CIPHER)**

[![PyPI version](https://img.shields.io/pypi/v/cipher-parse.svg)](https://pypi.python.org/pypi/cipher-parse) ![example workflow](https://github.com/LightForm-group/cipher-parse/actions/workflows/test.yml/badge.svg) [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/LightForm-group/cipher-parse/HEAD)


Click the Binder link above to try it out.

## Acknowledgements
cipher-parse was developed using funding from the [LightForm](https://lightform.org.uk/) EPSRC programme grant ([EP/R001715/1](https://gow.epsrc.ukri.org/NGBOViewGrant.aspx?GrantRef=EP/R001715/1))


<img src="https://lightform-group.github.io/wiki/assets/images/site/lightform-logo.png" width="150"/>
